@@ -22,23 +22,27 @@ This class has following LDAP operation methods.
 * compare_
 * whoami_
 * passwd_
-* start_tls
-* set_option
-* get_option
-* abandon
+* start_tls_
+* set_option_
+* get_option_
+* abandon_
 * cancel
-* result
+* result_
 * search_result
 
 __init__
 --------
 
 LDAP constructor receives uri parameter.
-Example.
 
     >>> from libldap import LDAP
     >>> ld = LDAP('ldap://localhost')
 
+You can specify uri parameter with list type:
+
+    >>> from libldap import LDAP
+    >>> ld = LDAP(['ldap://someserver.example.com/', 'ldap://localhost/'])
+
 LDAP class supports context manager. You can write your code like this:
 
     >>> from libldap import LDAP, LDAP_SCOPE_BASE
@@ -58,6 +62,11 @@ Otherwise LDAP instance is still anonymous.
 
 After closing **with statement**, LDAP instance executes unbind() method.
 
+You can specify LDAPS uri. This initiate TLS processing on an LDAP session.
+
+    >>> from libldap import LDAP
+    >>> ld = LDAP('ldaps://localhost')
+
 bind
 -----
 
@@ -162,11 +171,10 @@ For example:
       'userPassword': [b'{SSHA}j3mvviOTZ1Or8dtvn/PRVjX1igZFnUnp']}]
 
 
+Each entry is dict-like object and value type is list.
+You can get *dn* value by accessing object attribute.
 
-Each entry is dict type and value type is list. **dn** attribute is also included
-in entry object.
-
-You can only specified attributes by **attributes** parameter. If `*` or None are
+You can get only specified attributes by **attributes** parameter. If `*` or None are
 specified, all attributes are fetched. **attrsonly** parameter fetchs attribute names
 only (value is empty list).
 
@@ -212,7 +220,7 @@ paged_search() is generator.
 add
 ---
 
-This is the method for LDAP add operation. Add method requires dn and
+This is the method for LDAP add operation. This method requires dn and
 LDAP attributes parameters. LDAP attributes type is [(str, [str])].
 
 Following is LDIF entry that we want to add.
@@ -257,7 +265,7 @@ Example.
 modify
 ------
 
-This is the method for LDAP modify operation. Modify method requires dn and
+This is the method for LDAP modify operation. This method requires dn and
 changes parameters. Changes type is [(str, [str], int)].
 
 Following is LDIF entry that we want to modify.
@@ -296,7 +304,7 @@ Example.
 delete
 -------
 
-This is the method for LDAP delete operation. Delete method requires dn parameter.
+This is the method for LDAP delete operation. This method requires dn parameter.
 
 Example.
 
@@ -310,7 +318,7 @@ Example.
 rename
 ------
 
-This is the method for LDAP rename operation. Rename method requires dn and
+This is the method for LDAP rename operation. This method requires dn and
 newrdn parameters. newparent and deleteoldrdn are optional parameters. if
 newparent parameter is None, newparent is same suffix with dn parameter.
 
@@ -332,7 +340,7 @@ Example.
 compare
 --------
 
-This is the method for LDAP compare operation. Compare method requires dn, attribute
+This is the method for LDAP compare operation. This method requires dn, attribute
 and value parameters. It returns boolean, specified attribute description and value
 to compare to those found in the entry or not.
 
@@ -367,7 +375,7 @@ passwd
 -------
 
 This is the method for LDAP passwd extended operation.
-Passwd method requires user parameter. oldpw and newpw parameters are optional.
+This method requires user parameter. oldpw and newpw parameters are optional.
 If oldpw is None, authentication will be skipped. If newpw is None, random password
 will be set.
 
@@ -389,6 +397,74 @@ Passwd method returns new password if succeeded.
         raise LDAPError(**result)
     libldap.core.LDAPError: Server is unwilling to perform (53)
 
+start_tls
+---------
+
+This is used to initiate TLS processing on an LDAP session. This sends *StartTLS*
+request to a server.
+
+.. code-block:: python
+
+    >>> from libldap import LDAP
+    >>> ld = LDAP('ldap://localhost')
+    >>> ld.start_tls()
+
+set_option
+----------
+
+This is used to set LDAP options to LDAP session or global settings.
+This method requires *option* and *value* parameters. *is_global* specifies
+option is set globally or not.
+LDAP sessions inherit their default settings from the global options in effect
+at the time the handle is created.
+
+Available option parameters are defined in **ldap.constants.LDAP.set_option**
+
+.. code-block:: python
+
+    >>> from libldap import LDAP, LDAP_OPT_X_TLS_REQUIRE_CERT, LDAP_OPT_X_TLS_TRY
+    >>> ld = LDAP('ldap://localhost')
+    >>> ld.set_option(LDAP_OPT_X_TLS_REQUIRE_CERT, LDAP_OPT_X_TLS_TRY, is_global=True)
+
+get_option
+----------
+
+This is used to get LDAP options of LDAP session or global settings.
+This method requires *option* parameter. You can get global settings option by
+specifying *is_global* parameter.
+
+Available option parameters are defined in **ldap.constants.LDAP.get_option**
+
+.. code-block:: python
+
+    >>> from libldap import LDAP, LDAP_OPT_X_TLS_REQUIRE_CERT
+    >>> ld = LDAP('ldap://localhost')
+    >>> ld.get_option(LDAP_OPT_X_TLS_REQUIRE_CERT, is_global=True)
+    2
+
+abandon
+--------
+
+This is used to send a LDAP Abandon request for an operation in progress.
+
+result
+-------
+
+This is used to wait for and return the result of an operation previously
+initiated by one of the LDAP asynchronous operation.
+
+.. code-block:: python
+
+    >>> from pprint import pprint
+    >>> from libldap import LDAP
+    >>> ld = LDAP('ldap://localhost')
+    >>> msgid = ld.bind('cn=master,dc=example,dc=com', 'secret', async=True)
+    >>> result = ld.result(msgid)
+    {'error_message': None,
+     'message': 'Invalid credentials',
+     'referrals': [],
+     'return_code': 49}
+
 LDAPControl
 ===========
 
